#
# spec file for package python-blaze
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  tests
Name:           python-blaze
Version:        0.11.3
Release:        1.3
Summary:        NumPy and Pandas interface to Big Data
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/blaze/blaze
Source:         https://github.com/blaze/blaze/archive/%{version}.tar.gz
BuildRequires:  %{python_module DataShape}
BuildRequires:  %{python_module Flask >= 0.10.1}
BuildRequires:  %{python_module Flask-Cors}
BuildRequires:  %{python_module SQLAlchemy >= 0.8.0}
BuildRequires:  %{python_module dask-dataframe}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module multipledispatch >= 0.4.7}
BuildRequires:  %{python_module numpy >= 1.7}
BuildRequires:  %{python_module odo >= 0.4.0}
BuildRequires:  %{python_module pandas >= 0.15.0}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toolz}
BuildRequires:  fdupes
BuildRequires:  python-contextlib2
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module PyHive >= 0.2.1}
BuildRequires:  %{python_module PyMySQL >= 0.7}
BuildRequires:  %{python_module PyYAML >= 3.11}
BuildRequires:  %{python_module bcolz >= 0.12.0}
BuildRequires:  %{python_module bokeh >= 0.12}
BuildRequires:  %{python_module boto >= 2.43.0}
BuildRequires:  %{python_module cytoolz}
BuildRequires:  %{python_module dask-all >= 0.11.1}
BuildRequires:  %{python_module h5py >= 2.6.0}
BuildRequires:  %{python_module numba >= 0.29.0}
BuildRequires:  %{python_module paramiko >= 2.0.0}
BuildRequires:  %{python_module psycopg2 >= 2.6.0}
BuildRequires:  %{python_module pymongo > 2.9.0}
BuildRequires:  %{python_module pytest >= 3.0.3}
BuildRequires:  %{python_module pytest-cov >= 2.0.0}
BuildRequires:  %{python_module requests >= 2.0.0}
BuildRequires:  %{python_module sas7bdat >= 2.0.0}
BuildRequires:  %{python_module tables >= 3.3.0}
%endif
Requires:       python-DataShape
Requires:       python-Flask >= 0.10.1
Requires:       python-Flask-Cors
Requires:       python-SQLAlchemy >= 0.8.0
Requires:       python-dask-dataframe
Requires:       python-multipledispatch >= 0.4.7
Requires:       python-numpy >= 1.7
Requires:       python-odo >= 0.4.0
Requires:       python-pandas >= 0.15.0
Requires:       python-psutil
Requires:       python-toolz
Recommends:     python-PyHive >= 0.2.1
Recommends:     python-PyMySQL >= 0.7
Recommends:     python-PyYAML >= 3.11
Recommends:     python-bokeh >= 0.12
Recommends:     python-boto >= 2.43.0
Recommends:     python-cytoolz
Recommends:     python-dask-all >= 0.11.1
Recommends:     python-h5py >= 2.6.0
Recommends:     python-numba >= 0.29.0
Recommends:     python-paramiko >= 2.0.0
Recommends:     python-psycopg2 >= 2.6.0
Recommends:     python-pymongo > 2.9.0
Recommends:     python-pytest >= 3.0.3
Recommends:     python-pytest-cov >= 2.0.0
Recommends:     python-requests >= 2.0.0
Recommends:     python-sas7bdat >= 2.0.0
Recommends:     python-tables >= 3.3.0
%ifpython2
Requires:       python-contextlib2
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%python_subpackages

%description
Blaze translates a subset of modified NumPy and Pandas-like syntax to
databases and other computing systems.  Blaze allows Python users a familiar
interface to query data living in other data storage systems.

%prep
%setup -q -n blaze-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/blaze-server

%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/blaze/server/spider.py
# Fix wrong-script-interpreter
sed -i "s|#!/usr/bin/env python|#!%__$python|" %{buildroot}%{$python_sitelib}/blaze/server/spider.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/blaze/server/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/blaze/server/
%fdupes %{buildroot}%{$python_sitelib}
}

%post
%python_install_alternative blaze-server

%postun
%python_uninstall_alternative blaze-server

%if %{with test}
%check
pushd blaze/tests
PYTHONPATH="%{buildroot}%{python_sitelib}" py.test blaze
popd
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst LICENSE.txt
%python_alternative %{_bindir}/blaze-server
%{python_sitelib}/*

%changelog
* Wed Sep  6 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to 0.11.3
  * Clean up naked asserts
- Update to 0.11.2
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.11.2.txt
- Update to 0.11.1
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.11.1.txt
- Update to 0.11.0
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.11.0.txt
- Update to 0.10.2
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.10.2.txt
- Update to 0.10.1
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.10.1.txt
- Update to 0.10.0
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.10.0.txt
- Update to 0.9.1
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.9.1.txt
- Update to 0.9.0
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.9.0.txt
- Update to 0.8.3
  * See: https://github.com/blaze/blaze/blob/0.11.3/docs/source/whatsnew/0.8.3.txt
* Fri Jul 10 2015 toddrme2178@gmail.com
- Update to 0.8.2
  + Bug Fixes
  * Fix broken sdist tarball
- Update to 0.8.1
  + New Expressions
  * String arithmetic is now possible across the numpy and pandas backends
    via the ``+`` (concatenation) and ``*`` (repeat) operators
  * Datetime arithmetic is now available (:issue:`1112`).
  * Add a :class:`~blaze.expr.collections.Concat` expression that implements
    Union-style operations
  * Add a :class:`~blaze.expr.expressions.Coerce` expression that casts
    expressions to a different datashape. This maps to ``astype`` in numpy
    and ``cast`` in SQL (:issue:`1137`).
  + Improved Expressions
  * :class:`~blaze.expr.expressions.ReLabel` expressions ``repr`` differently
    depending on whether the existing column names are valid Python variable
    names (:issue:`1070`).
  + Improved Backends
  * CSV
  * In-memory merges of CSV files are now possible (:issue:`1121`).
  * Blaze Server
  * Tie blueprint registration to data registration (:issue:`1061`).
  * Don't catch import error when flask doesn't exist, since blaze does
    this in its ``__init__.py`` (:issue:`1087`).
  * Multiple serialization formats including JSON, pickle, and msgpack are
    now available. Additionally, one can add custom serialization formats
    with this implementation (:issue:`1102`, :issue:`1122`).
  * Add a ``'names'`` field to the response of the ``compute.<format>``
    route for Bokeh compatibility (:issue:`1129`).
  * Add cross origin resource sharing for Bokeh compatibility
  * Add a command line interface (:issue:`1115`).
  * Add a way to tell the blaze server command line interface what to
    server via a YAML file (:issue:`1115`).
  * SQL
  * Use aliases to allow expressions on the SQL backend that involve a
    multiple step reduction operation (:issue:`1066`, :issue:`1126`).
  * Fix unary not operator ``~`` (:issue:`1091`).
  * Postgres uses ``==`` to compare ``NaN`` so we do it that way as well
    for the postgresql backend (:issue:`1123`).
  * Find table inside non-default schema when serving off a SQLAlchemy
    ``MetaData`` object (:issue:`1145`).
  + API Changes
  * Remove old :func:`~blaze.server.client.ExprClient`. Use
    :class:`~blaze.server.client.Client` instead (:issue:`1154`).
  * Make sort + slice and sort + slice semantics of the SQL backend reflect
    those of numpy (:issue:`1125`).
  * The following syntax is no longer allowed for Blaze server:
    >>> Data('blaze://localhost::accounts')  # error # doctest: +SKIP
    Use this syntax instead:
    >>> Data('blaze://localhost').accounts  # valid # doctest: +SKIP
  + Bug Fixes
  * Handle SQLAlchemy API churn around reference of ``ColumnElement``
    objects in the 1.0.x series (:issue:`1071`, :issue:`1076`).
  * Obscure hashing bug when passing in both a pandas Timestamp and a
    ``datetime.datetime`` object. Both objects hash to the same value but
    don't necessarily compare equal; this makes Python call ``__eq__`` which
    caused an ``Eq`` expression to be constructed (:issue:`1097`).
  * Properly handle ``And`` expressions that involve the same field in
    MongoDB (:issue:`1099`).
  * Handle Dask API changes (:issue:`1114`).
  * Use the ``date`` function in SQLAlchemy when getting the ``date``
    attribute of a ``datetime`` dshaped expression. Previously this was
    calling extract, which is incorrect for the postgres backend.
  * Fix API compatibility with different versions of psutil (:issue:`1136`).
  * Use explicit ``int64`` comparisons on Windows, since the default values
    may be different (:issue:`1148`).
  * Fix name attribute propagation in pandas ``Series`` objects
  * Raise a more informative error when trying to subset with an unsupported
    expression in the MongoDB backend (:issue:`1155`).
- update to version 0.8.0:
  * many changes, see https://github.com/ContinuumIO/blaze/compare/0.7.3...0.8.0
* Tue Mar  3 2015 toddrme2178@gmail.com
- Initial version
